@@ -65,7 +65,9 @@
 #' linked significant QTL. The position near the position of the known
 #' QTLs under this distance will not be consider as the candidate position
 #' in the search process.
-#' @param conv numeric. The convergence criterion of EM algorithm.
+#' @param link logical. If being False, positions on the same chromosomes
+#' as the known QTLs will not be searched.
+#' @param crit numeric. The convergence criterion of EM algorithm.
 #' The E and M steps will be iterated until a convergence criterion
 #' is satisfied.
 #' @param console logical. To decide whether the process of algorithm will
@@ -113,8 +115,8 @@
 #' result$QTL.best
 #' result$effect.best
 MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL, tR = NULL, method = "EM",
-                        type = "RI", D.matrix = NULL, ng = 2, cM = TRUE, speed = 1, QTLdist = 15, conv = 10^-3,
-                        console = TRUE){
+                        type = "RI", D.matrix = NULL, ng = 2, cM = TRUE, speed = 1, QTLdist = 15, link = TRUE,
+                        crit = 10^-3, console = TRUE){
 
   if(is.null(QTL) | is.null(marker) | is.null(geno) |  is.null(y)){
     stop("Input data is missing, please cheak and fix.", call. = FALSE)
@@ -207,6 +209,7 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
   ng <- round(ng)
 
   if(!cM[1] %in% c(0,1) | length(cM > 1)){cM <- TRUE}
+  if(!link[1] %in% c(0,1) | length(link > 1)){link <- TRUE}
 
   if(!is.numeric(speed) | length(speed) > 1 | min(speed) < 0){
     stop("Parameter speed error, please input a positive number.", call. = FALSE)
@@ -216,8 +219,8 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
     stop("Parameter QTLdist error, please input a bigger positive number.", call. = FALSE)
   }
 
-  if(!is.numeric(conv) | length(conv) > 1 | min(conv) < 0){
-    stop("Parameter conv error, please input a positive number.", call. = FALSE)
+  if(!is.numeric(crit) | length(crit) > 1 | min(crit) < 0){
+    stop("Parameter crit error, please input a positive number.", call. = FALSE)
   }
 
   if(!console[1] %in% c(0,1) | length(console) > 1){console <- TRUE}
@@ -234,9 +237,9 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
   if(console){cat("chr", "cM", "LRT", "log.likelihood", "known QTL", "\n", sep = "\t")}
 
   if(method == "EM"){
-    meth <- function(QTL, marker, geno, D.matrix, y, yu, tL, tR, type, ng, sele.g, conv){
+    meth <- function(QTL, marker, geno, D.matrix, y, yu, tL, tR, type, ng, sele.g, crit){
       EM <- EM.MIM2(QTL, marker, geno, D.matrix, y = y, yu = yu, tL = tL, tR = tR, type = type,
-                    ng = ng, sele.g = sele.g, conv = conv, console = FALSE)
+                    ng = ng, sele.g = sele.g, crit = crit, console = FALSE)
       eff <- as.numeric(EM$E.vector)
       mu0 <- as.numeric(EM$beta)
       sigma <- sqrt(as.numeric(EM$variance))
@@ -401,7 +404,7 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
       return(re)
     }
 
-    meth <- function(QTL, marker, geno, D.matrix, y, yu, tL, tR, type, ng,sele.g, conv){
+    meth <- function(QTL, marker, geno, D.matrix, y, yu, tL, tR, type, ng,sele.g, crit){
       mp <- switch(sele.g,
                    p = mixprop(QTL, length(yu), marker, geno, model = 1, cM = cM, type = type, ng = ng)[[2]],
                    t = mixprop(QTL, length(yu), marker, geno, model = 2, cM = cM, type = type, ng = ng)[[2]],
@@ -445,9 +448,17 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
 
   effect <- c()
   cr0 <- sort(unique(marker[, 1]))
+  if(!link){
+    cr0 <- cr0[!cr0 %in% QTL[, 1]]
+  }
+  if(length(cr0) < 1){
+    stop("No searchable positions.", call. = FALSE)
+  }
   for(i in cr0){
     cr <- marker[marker[, 1] == i,]
-    QTLs0 <- seq(ceiling(floor(min(cr[,2]))+speed), (max(cr[,2])), speed)
+    minpos <- min(cr[, 2])+speed
+    if(speed%%1 == 0){minpos = ceiling(floor(min(cr[, 2]))+speed)}
+    QTLs0 <- seq(minpos, (max(cr[,2])), speed)
     QTLc0 <- QTL[QTL[, 1] == i,]
     if(ncol(as.matrix(QTLc0))==1){
       QTLc0 = t(as.matrix(QTLc0))
@@ -459,7 +470,7 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
     }
     for(j in QTLs0){
       QTL0 <- rbind(QTL, c(i,j))
-      fit0 <- meth(QTL0, marker, geno, D.matrix, y, yu, tL, tR, type, ng, sele.g, conv)
+      fit0 <- meth(QTL0, marker, geno, D.matrix, y, yu, tL, tR, type, ng, sele.g, crit)
       effect0 <- c(t(QTL0), fit0[[1]], fit0[[4]], fit0[[5]], fit0[[6]])
 
       LRT0 <- round(effect0[length(effect0)-2], 3)
@@ -484,7 +495,7 @@ MIM.search2 <- function(QTL, marker, geno, y, yu = NULL, sele.g = "n", tL = NULL
     bs <- rbind(bs, eff1[b5+1,])
   }
 
-  best <- bs[bs[,ncol(bs)] == max(bs[,ncol(bs)]),]
+  best <- bs[bs[,ncol(bs)-1] == max(bs[,ncol(bs)-1]),]
   QTL.best <- matrix(best[1:(2*nq)], nq, 2, byrow = TRUE)
   colnames(QTL.best) <- c("chromosome", "position(cM)")
   row.names(QTL.best) <- c(paste("QTL", 1:(nq-1)), "QTL new")
